class Metadata:
    IP_ADDRESS: str = "x-forwarded-for"
    USER_AGENT: str = "x-user-agent"
